document.addEventListener("DOMContentLoaded", function () {
  const calculateButton = document.getElementById("calculate_button");
  const calculatedPriceField = document.getElementById("calculated_price");
  const priceField = document.getElementById("price");

  if (calculateButton) {
    calculateButton.addEventListener("click", async function () {
      try {
        // Retrieve values directly from form fields
        const typeValue = document.getElementById("type").value;
        const propertyTypeValue = document.getElementById("property_type").value;
        const areaValue = parseFloat(document.getElementById("area").value.trim());
        const roomCountValue = parseInt(document.getElementById("room_count").value.trim(), 10);
        const floorValue = parseInt(document.getElementById("floor").value.trim(), 10);
        const floorCountValue = parseInt(document.getElementById("floor_count").value.trim(), 10);

        // Ensure all fields are filled
        if (
          !typeValue ||
          !propertyTypeValue ||
          isNaN(areaValue) ||
          isNaN(roomCountValue) ||
          isNaN(floorValue) ||
          isNaN(floorCountValue)
        ) {
          alert("Please fill in all fields with valid values to calculate the price.");
          return;
        }

        // Send the parameters directly to the server
        const response = await fetch("/api/properties/calculate_price", {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
            "x-csrf-token": document.querySelector("meta[name='csrf-token']").content,
          },
          body: JSON.stringify({
            type: typeValue,
            property_type: propertyTypeValue,
            area: areaValue,
            room_count: roomCountValue,
            floor: floorValue,
            floor_count: floorCountValue,
          }),
        });

        if (response.ok) {
          const data = await response.json();
          calculatedPriceField.value = data.calculated_price;
          // Automatically copy the calculated price to the price field
          priceField.value = data.calculated_price;
        } else {
          const errorData = await response.json();
          alert(`Error calculating price: ${errorData.error || "Unknown error"}`);
        }
      } catch (error) {
        console.error("Error:", error);
        alert("An error occurred while calculating the price.");
      }
    });
  }
});
