defmodule UserLoginContext do
  use WhiteBread.Context
  use Hound.Helpers
  alias PropTrackr.Accounts
  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User

  scenario_starting_state fn _state ->
    Ecto.Adapters.SQL.Sandbox.checkout(PropTrackr.Repo)
    Ecto.Adapters.SQL.Sandbox.mode(PropTrackr.Repo, {:shared, self()})
    Hound.start_session()
    %{}
  end

  scenario_finalize fn _status, _state ->
    Ecto.Adapters.SQL.Sandbox.checkin(PropTrackr.Repo)
    Hound.end_session()
  end

  given_ ~r/^there exists following accounts$/, fn state, %{table_data: table} ->
    table                                                                                
    |> Enum.map(fn user_details -> User.changeset(%User{}, user_details) end)                            
    |> Enum.each(fn changeset -> Repo.insert!(changeset) end)

    existing_user = List.first(table)

    {
      :ok,
      state
      |> Map.put(:email, existing_user[:email])
      |> Map.put(:password, existing_user[:password])
    }
  end

  and_ ~r/^I want to log in$/, fn state ->
    navigate_to("/login")
    {:ok, state}
  end

  and_ ~r/^I enter valid credentials$/, fn state ->
    insert_credentials(state[:email], state[:password])
    {:ok, state}
  end

  when_ ~r/^I click the login button$/, fn state ->
    click({:id, "login_button"})
    {:ok, state}
  end

  then_ ~r/^I should be logged in$/, fn state ->
    assert visible_in_page? ~r"Successfully logged in!"
    {:ok, state}
  end

  and_ ~r/^I should be redirected to the homepage$/, fn state ->
    assert current_path() == "/"
    {:ok, state}
  end

  and_ ~r/^I enter credentials with invalid email$/, fn state ->
    insert_credentials("obviously.invalid@gmail.com", "password_idk")
    {:ok, state}
  end

  then_ ~r/^I should receive an error message stating invalid email$/, fn state ->
    assert visible_in_page? ~r"Given email does not exist!"
    {:ok, state}
  end

  and_ ~r/^I should be shown the log in form again$/, fn state ->
    assert visible_in_page? ~r"Sign in to PropTrackr"
    {:ok, state}
  end

  and_ ~r/^I enter credentials with invalid password$/, fn state ->
    insert_credentials(state[:email], "obviously_invalid")
    {:ok, state}
  end

  then_ ~r/^I should receive an error message stating invalid password$/, fn state ->
    assert visible_in_page? ~r"Invalid credentials!"
    {:ok, state}
  end

  defp insert_credentials(email, password) do
    fill_field({:id, "email"}, email)
    fill_field({:id, "password"}, password)
  end

end
