defmodule PropTrackrWeb.FavoriteController do
  use PropTrackrWeb, :controller

  import Ecto.Query
  alias PropTrackr.Repo
  alias PropTrackr.Properties.Property
  alias PropTrackr.Favorites.Favorite

  def create(conn, %{"reference" => reference}) do
    current_user = conn.assigns.current_user

    if current_user == nil do
      conn
      |> put_status(:unauthorized)
      |> json(%{error: "You're not logged in!"})
    else
      case Repo.one(from p in Property, where: p.reference == ^reference) do
        nil ->
          conn
          |> put_status(:not_found)
          |> json(%{error: "Property not found"})

        property ->
          if property.user_id == current_user.id do
            conn
            |> put_status(:forbidden)
            |> json(%{error: "Cannot set own property as favorite"})
          else
            favorite_changeset = %Favorite{}
            |> Favorite.changeset(%{
              user_id: current_user.id,
              property_id: property.id
            })

            case Repo.insert(favorite_changeset) do
              {:ok, _favorite} ->
                conn
                |> render(:message, message: "Property added to favorites")
              {:error, _changeset} ->
                conn
                |> put_status(:unprocessable_entity)
                |> render(:error, error: "Already in favorites")
            end
          end
      end
    end
  end

  def delete(conn, %{"reference" => reference}) do
    current_user = conn.assigns.current_user

    if current_user == nil do
      conn
      |> put_status(:unauthorized)
      |> json(%{error: "You must be logged in"})
    else
      case Repo.one(from p in Property, where: p.reference == ^reference) do
        nil ->
          conn
          |> put_status(:not_found)
          |> json(%{error: "Property not found"})

        property ->
          favorite = Repo.one(
            from f in Favorite,
            where: f.user_id == ^current_user.id and f.property_id == ^property.id
          )

          case favorite do
            nil ->
              conn
              |> put_status(:not_found)
              |> json(%{error: "Favorite not found"})

            favorite ->
              case Repo.delete(favorite) do
                {:ok, _} ->
                  json(conn, %{message: "Property removed from favorites"})
                {:error, _} ->
                  conn
                  |> put_status(:internal_server_error)
                  |> json(%{error: "Failed to remove favorite"})
              end
          end
      end
    end
  end

end
