defmodule PropTrackrWeb.PasswordController do
  use PropTrackrWeb, :controller
  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User
  import Ecto.Query, only: [from: 2]

  def index(conn, _params) do
    user_id = get_session(conn, :user_id)
    if user_id == nil do
      conn
      |> put_flash(:error, "You are not logged in!")
      |> redirect(to: ~p"/login")
    else
      render conn, "index.html"
    end
  end

  def create(conn, %{"current_password" => current_password, "new_password" => new_password, "new_password_confirmation" => new_password_confirmation}) do
    cond do
      new_password != new_password_confirmation ->
        conn
        |> put_flash(:error, "New passwords don't match!")
        |> render("index.html")
      new_password == current_password ->
        conn
        |> put_flash(:error, "New password can't be the same as the old password!")
        |> render("index.html")
      true ->
        user_id = get_session(conn, :user_id)
        user = Repo.get(User, user_id)

        if Bcrypt.verify_pass(current_password, user.hashed_password) do
          hashed_new_password = Bcrypt.hash_pwd_salt(new_password)
          {row_count, _} = from(u in User, where: u.id == ^user_id, select: u)
          |> Repo.update_all(set: [hashed_password: hashed_new_password])

          if row_count == 1 do
            conn
            |> delete_session(:user_id)
            |> put_flash(:info, "Password changed successfully! Please log in again")
            |> redirect(to: ~p"/login")
          else
            conn
            |> put_flash(:error, "Unknown error has occurred!")
            |> redirect(to: ~p"/")
          end
        else
          conn
          |> put_flash(:error, "Invalid current password!")
          |> render("index.html")
        end
    end
  end
end
