# lib/proptrackr_web/controllers/theme_controller.ex
defmodule PropTrackrWeb.ThemeController do
  use PropTrackrWeb, :controller
  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo

  def update(conn, %{"is_dark_mode" => is_dark_mode}) do
    case conn.assigns.current_user do
      nil ->
        conn
        |> put_status(:unauthorized)
        |> json(%{error: "User not authenticated"})

      user ->
        # Update user directly using Repo
        case Repo.update(Ecto.Changeset.change(user, %{is_dark_mode: is_dark_mode})) do
          {:ok, updated_user} ->
            # Update session with new theme preference
            conn
            |> put_session(:user_theme, updated_user.is_dark_mode)
            |> json(%{success: true, is_dark_mode: updated_user.is_dark_mode})

          {:error, _changeset} ->
            conn
            |> put_status(:unprocessable_entity)
            |> json(%{error: "Could not update theme preference"})
        end
    end
  end
end
