defmodule PropTrackr.Authentication do
  import Plug.Conn
  import Phoenix.Controller, only: [put_flash: 3]

  def init(opts) do
    opts[:repo]
  end

  def call(conn, repo) do
    user_id = get_session(conn, :user_id)
    user = user_id && repo.get(PropTrackr.Accounts.User, user_id)
    if user do
      login(conn, user_id, user)
    else
      assign(conn, :current_user, nil)
    end
  end

  def login(conn, user_id, user) do
    assign(conn, :current_user, user)
    |> put_session(:user_id, user_id)
  end

  def logout(conn) do
    conn
    |> assign(:current_user, nil)
    |> delete_session(:user_id)
  end

  def validate_credentials(conn, email, password, [repo: repo]) do
    user = repo.get_by(PropTrackr.Accounts.User, email: email)
    cond do
      user == nil ->
        {:error, :invalid_email, conn}
      Bcrypt.verify_pass(password, user.hashed_password) ->
        {:ok, conn |> login(user.id, user)}
      true ->
        {:error, :unauthorized, conn}
    end
  end
end
