defmodule PropTrackrWeb.LogoutControllerTest do
  use PropTrackrWeb.ConnCase
  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo

  @password "password123"

  setup do
    user = %User{
      name: "Test",
      surname: "User",
      birth_date: ~D[2000-01-01],
      phone_number: "000",
      bio: "Yo",
      email: "test.user@gmail.com",
      password: @password,
      confirm_password: @password,
      hashed_password: Bcrypt.hash_pwd_salt(@password)
    }
    Repo.insert!(user)

    :ok
  end

  test "Authenticated user should be able to logout and be redirected to the homepage", %{conn: conn} do
    # First login the user
    conn = conn
           |> post("/login", %{"email" => "test.user@gmail.com", "password" => "password123"})

    # Verify logged in
    assert get_session(conn, :user_id)

    # Perform logout
    conn = get(conn, "/logout")
    assert redirected_to(conn) == "/"
    conn = get(conn, redirected_to(conn))
    assert html_response(conn, 200)
    assert get_flash(conn, :info) =~ ~r/You are successfully logged out/
    refute get_session(conn, :user_id)
  end

  test "Unauthenticated user should be redirected to homepage with message", %{conn: conn} do
    conn = get(conn, "/logout")
    assert redirected_to(conn) == "/"
    conn = get(conn, redirected_to(conn))
    assert html_response(conn, 200)
    assert get_flash(conn, :info) =~ ~r/You are not logged in/
  end

end
